---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
Please provide a clear and concise description of what the bug is. 
What is happening, and what do you expect to happen. Share any Python
tracebacks if they apply. 


**System Information:**
Some bugs can be specific to a platform, or related to GPU drivers. To help
us troubleshoot, share the output of the `python -m pyglet.info` command. If this
is not possible, please provide the OS type and release, as well as the type of
GPU (ex: Windows 10 64-bit, AMD RX580 GPU).


**How To Reproduce**
A small code example that illustrates how to reproduce the bug is very useful to help triage.
